@@ -32,8 +32,8 @@ convert_df <- function(x) {
 # election date entry
 electiondate2date <- function(x) {
     if (is.null(x)) {
-        NA_character_
+        as.Date(NA_character_)
     } else {
-        sprintf("%d-%d-%d", x$year, x$month, x$day)
+        as.Date(x, "%Y-%m-%d")
     }
 }
